summaryrefslogtreecommitdiffstats
path: root/dcop/dcopidl
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /dcop/dcopidl
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'dcop/dcopidl')
-rw-r--r--dcop/dcopidl/scanner.cc16
-rw-r--r--dcop/dcopidl/scanner.ll4
-rw-r--r--dcop/dcopidl/yacc.cc2
-rw-r--r--dcop/dcopidl/yacc.yy2
4 files changed, 12 insertions, 12 deletions
diff --git a/dcop/dcopidl/scanner.ll b/dcop/dcopidl/scanner.ll
index 63e8ca59c..62a80cdd8 100644
--- a/dcop/dcopidl/scanner.ll
+++ b/dcop/dcopidl/scanner.ll
@@ -169,8 +169,8 @@ Kidl_Identifier [_a-zA-Z][a-zA-Z0-9_]*
}
"#include"[ \t]*[<\"][^>"]*[>\"]\s*\n {
TQString s( yytext );
- int i = s.find(TQRegExp("[\"<]"))+1;
- int j = s.find(TQRegExp("[\">]"), i);
+ int i = s.tqfind(TQRegExp("[\"<]"))+1;
+ int j = s.tqfind(TQRegExp("[\">]"), i);
yylval._str = new TQString( s.mid( i, j - i ) );
idl_line_no++;
return T_INCLUDE;
diff --git a/dcop/dcopidl/yacc.cc b/dcop/dcopidl/yacc.cc
index d41fa6dbd..1fbc4c0bd 100644
--- a/dcop/dcopidl/yacc.cc
+++ b/dcop/dcopidl/yacc.cc
@@ -1643,7 +1643,7 @@ yyreduce:
case 15:
#line 221 "yacc.yy"
{
- int pos = in_namespace.findRev( "::", -3 );
+ int pos = in_namespace.tqfindRev( "::", -3 );
if( pos >= 0 )
in_namespace = in_namespace.left( pos + 2 );
else
diff --git a/dcop/dcopidl/yacc.yy b/dcop/dcopidl/yacc.yy
index ca22c65e1..7870eb6e9 100644
--- a/dcop/dcopidl/yacc.yy
+++ b/dcop/dcopidl/yacc.yy
@@ -219,7 +219,7 @@ declaration
}
main T_RIGHT_CURLY_BRACKET opt_semicolon
{
- int pos = in_namespace.findRev( "::", -3 );
+ int pos = in_namespace.tqfindRev( "::", -3 );
if( pos >= 0 )
in_namespace = in_namespace.left( pos + 2 );
else
diff --git a/dcop/dcopidl/scanner.cc b/dcop/dcopidl/scanner.cc
index e91b21d68..edc8ac567 100644
--- a/dcop/dcopidl/scanner.cc
+++ b/dcop/dcopidl/scanner.cc
@@ -803,7 +803,7 @@ static int yy_lp;
*yy_cp = yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yy_full_match; /* restore poss. backed-over text */ \
++yy_lp; \
-goto find_rule; \
+goto tqfind_rule; \
}
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
@@ -1140,11 +1140,11 @@ yy_match:
}
while ( yy_current_state != 310 );
-yy_find_action:
+yy_tqfind_action:
yy_current_state = *--yy_state_ptr;
yy_lp = yy_accept[yy_current_state];
-find_rule: /* we branch to this label when backing up */
- for ( ; ; ) /* until we find what rule we matched */
+tqfind_rule: /* we branch to this label when backing up */
+ for ( ; ; ) /* until we tqfind what rule we matched */
{
if ( yy_lp && yy_lp < yy_accept[yy_current_state + 1] )
{
@@ -1226,8 +1226,8 @@ YY_RULE_SETUP
#line 170 "scanner.ll"
{
TQString s( yytext );
- int i = s.find(TQRegExp("[\"<]"))+1;
- int j = s.find(TQRegExp("[\">]"), i);
+ int i = s.tqfind(TQRegExp("[\"<]"))+1;
+ int j = s.tqfind(TQRegExp("[\">]"), i);
yylval._str = new TQString( s.mid( i, j - i ) );
idl_line_no++;
return T_INCLUDE;
@@ -1686,7 +1686,7 @@ ECHO;
else
{
yy_cp = yy_c_buf_p;
- goto yy_find_action;
+ goto yy_tqfind_action;
}
}
@@ -1739,7 +1739,7 @@ ECHO;
yy_cp = yy_c_buf_p;
yy_bp = yytext_ptr + YY_MORE_ADJ;
- goto yy_find_action;
+ goto yy_tqfind_action;
}
break;
}